"""
    runWorkflow(filename::String)

Executes a workflow defined in a file, utilizing the FACTWorkflowManager to handle the execution process. 
This function wraps the workflow execution in a try-catch block to gracefully handle any errors that 
may occur during the workflow run.

# Arguments
- `filename::String`: The path to the workflow definition file to be executed.

# Behavior
- The function attempts to run the workflow specified in `filename` using the FACTWorkflowManager.
- If an error occurs during the workflow execution, it catches the exception and prints an error message indicating that the workflow run encountered an issue.

# Example
To execute a workflow defined in 'workflow.toml':

> runWorkflow("workflow.toml")

This will initiate the execution of the workflow, with error handling in case of issues during the process.
"""
function runWorkflow(systemfilename::String, filename::String)
    registry = OrchestratorRegistry.deploy(systemfilename)
    try
        FACT_workflow_manager.run_file(filename, registry)       
    catch e
        println("An error occurred running worflow: ", e)
    end
end


